OC.L10N.register(
    "calendar",
    {
    "Calendar" : "달력",
    "Hello," : "안녕하세요,",
    "Cheers!" : "감사합니다!",
    "Too many redirects. Aborting ..." : "너무 많은 넘겨주기, 중단합니다 ...",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "원격 서버에서 달력 접근을 허용하지 않음 (HTTP 오류 {%s})",
    "Error connecting to remote server" : "원격 서버 연결 오류",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "원격 서버의 자원을 요청할 수 없습니다. 인증서가 일치하지 않을 수 있습니다",
    "Error requesting resource on remote server" : "원격 서버 자원 요청 오류",
    "Individual" : "개별",
    "Group" : "그룹",
    "Resource" : "자원",
    "Room" : "방",
    "Unknown" : "알 수 없음",
    "Required" : "필요함",
    "Optional" : "선택적",
    "Does not attend" : "참석하지 않음",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "알 수 없는 시간대({tz})에 있습니다. UTC를 대신 사용합니다",
    "Please create a calendar first." : "달력을 먼저 생성하십시오.",
    "New event" : "새 일정",
    "CalDAV address for clients" : "클라이언트를 위한 CalDAV 주소",
    "Error saving WebCal-calendar" : "WebCal 달력을 저장하는 중 오류 발생",
    "WebDAV address for subscriptions" : "구독에 사용할 WebDAV 주소",
    "group" : "그룹",
    "Details" : "자세한 정보",
    "Attendees" : "참석자",
    "Reminders" : "알림",
    "Repeating" : "반복",
    "When shared show full event" : "전체 일정 공유",
    "When shared show only busy" : "바쁨/한가함만 공유",
    "When shared hide this event" : "일정 공유하지 않음",
    "Confirmed" : "확인됨",
    "Tentative" : "예정됨",
    "Cancelled" : "취소됨",
    "Global" : "전역",
    "None" : "없음",
    "Every day" : "매일",
    "Every week" : "매주",
    "Every month" : "매월",
    "Every year" : "매년",
    "never" : "없음",
    "after" : "이후",
    "How about getting started by importing some calendars?" : "기존에 사용하던 달력을 가져오시겠습니까?",
    "At time of event" : "일정 정각",
    "5 minutes before" : "5분 전",
    "10 minutes before" : "10분 전",
    "15 minutes before" : "15분 전",
    "30 minutes before" : "30분 전",
    "1 hour before" : "1시간 전",
    "2 hours before" : "2시간 전",
    "Custom" : "사용자 정의",
    "Audio" : "오디오",
    "Pop-up" : "팝업",
    "sec" : "초",
    "min" : "분",
    "hours" : "시간",
    "days" : "일",
    "week" : "주",
    "before" : "이전",
    "start" : "시작",
    "end" : "끝",
    "Editing reminders of unknown type not supported." : "알 수 없는 형식의 미리 알림을 편집할 수 없습니다.",
    "Week {number} of {year}" : "{year}년 제 {number}주",
    "Successfully imported" : "성공적으로 가져옴",
    "Partially imported, 1 failure" : "일부만 가져옴, 1개 항목 실패",
    "Partially imported, {n} failures" : "일부만 가져옴, {n}개 항목 실패",
    "Audio alarm" : "오디오 알람",
    "{type} {time} before the event starts" : "일정 시작 {time} 전 {type}",
    "{type} {time} before the event ends" : "일정 종료 {time} 전 {type}",
    "{type} {time} after the event starts" : "일정 시작 {time} 후 {type}",
    "{type} {time} after the event ends" : "일정 종료 {time} 후 {type}",
    "{type} at the event's start" : "일정 시작 시 {type}",
    "{type} at the event's end" : "일정 종료 시 {type}",
    "{type} at {time}" : "{time}에 {type}",
    "{calendar} shared by {owner}" : "{owner} 님이 공유한 달력",
    "Please enter a valid WebCal-URL" : "올바른 WebCal URL을 입력하십시오",
    "Severe error in webcal proxy. Please contact administrator for more information." : "WebCal 프록시에서 오류가 발생했습니다. 시스템 관리자에게 연락하십시오.",
    "Title of the Event" : "일정 제목",
    "Starts" : "시작",
    "Ends" : "종료",
    "All day Event" : "종일 일정",
    "Delete" : "삭제",
    "Cancel" : "취소",
    "More ..." : "더 보기...",
    "Create" : "만들기",
    "Update" : "업데이트",
    "Close" : "닫기",
    "Location" : "위치",
    "Description" : "설명",
    "Event status" : "이벤트 상태",
    "Visibility when sharing" : "공유할 때 표시 여부",
    "Export" : "내보내기",
    "%s has published the calendar %s" : "%s 님이 달력 %s을(를) 공개했습니다",
    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "%s 님이 달력 {boldstart}%s{boldend}을(를) 공개했음을 알려 드립니다.",
    "Click here to access it" : "접근하려면 여기를 누르십시오",
    "We wanted to inform you that %s has published the calendar %s." : "%s 님이 달력 %s을(를) 공개했음을 알려 드립니다.",
    "Click on the link below to access it" : "접근하려면 아래의 링크를 누르십시오",
    "Day" : "일",
    "Week" : "주",
    "Month" : "달",
    "Today" : "오늘",
    "Some events in this calendar are broken. Please check the JS console for more info." : "이 달력의 일부 일정이 깨졌습니다. 더 많은 정보를 보려면 JS 콘솔을 참조하십시오.",
    "Share Calendar" : "달력 공유",
    "Shared" : "공유됨",
    "More" : "더 보기",
    "Edit" : "편집",
    "Link" : "링크",
    "iCal link" : "iCal 링크",
    "Download" : "다운로드",
    "Share with users or groups" : "사용자 및 그룹과 공유",
    "can edit" : "편집 가능",
    "Share link" : "링크 공유",
    "Public access" : "공개 접근",
    "Email link to person" : "링크를 이메일로 전송",
    "Send" : "보내기",
    "New Calendar" : "새 달력",
    "Name" : "이름",
    "New Subscription" : "새 구독",
    "Go back" : "뒤로 가기",
    "Go forward" : "앞으로 가기",
    "Edit event" : "일정 편집",
    "Delete Event" : "일정 삭제",
    "Save Event" : "일정 저장",
    "Time" : "시간",
    "Type" : "종류",
    "Relative" : "상대적",
    "Absolute" : "절대적",
    "Repeat" : "반복",
    "Add" : "추가",
    "Please add your email address in the personal settings in order to add attendees." : "참석자 목록을 편집하려면 개인 설정에서 이메일 주소를 추가하십시오.",
    "from" : "시작",
    "to" : "끝",
    "This event's repeating rule is not supported yet." : "이 일정의 반복 규칙은 아직 지원하지 않습니다.",
    "Support for advanced rules will be added with subsequent updates." : "고급 규칙 지원은 차후 업데이트로 추가됩니다.",
    "Reset repeating rule" : "반복 규칙 초기화",
    "Repeat every ..." : "다음마다 반복 ...",
    "end repeat ..." : "반복 끝 ...",
    "times" : "회",
    "Import Calendars" : "달력 가져오기",
    "Import canceled" : "가져오기 취소됨",
    "Analyzing calendar" : "달력 분석 중",
    "The file contains objects incompatible with the selected calendar" : "이 파일에 현재 달력과 호환되지 않는 객체가 들어 있습니다",
    "New calendar" : "새 달력",
    "File is empty" : "파일이 비어 있음",
    "Import scheduled" : "가져오기 예약됨",
    "Publish URL" : "URL 공개",
    "Settings & import" : "설정 및 가져오기",
    "Skip simple event editor" : "간단한 이벤트 편집기 건너뛰기",
    "Show week numbers" : "주 번호 보이기",
    "Import calendar" : "달력 가져오기",
    "No Calendars selected for import" : "가져올 달력을 선택하지 않았음",
    "Primary CalDAV address" : "주 CalDAV 주소",
    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV 주소"
},
"nplurals=1; plural=0;");
